@@ -2,6 +2,6 @@ import argparse
 
 parser = argparse.ArgumentParser()
 parser.add_argument("-p", "--print", help="Print the generated mutations", action="store_true")
-parser.add_argument("-s", "--submit", help="Submit the generated mutations to a CE", action="store_true", default=True)
+parser.add_argument("-s", "--submit", help="Submit the generated mutations to a CE", action="store_true", default=False)
 
-args = parser.parse_args()
\ No newline at end of file
+args = parser.parse_args()
